@@ -14,20 +14,45 @@
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-#include "json.hpp"
-#include <algorithm>
-#include <iostream>
-#include <fstream>
-#include <string>
-#include <cctype>
+
+#include "pluginsAdmin.h"
+
+#include <windows.h>
+
 #include <shlobj.h>
 #include <shlwapi.h>
-#include "pluginsAdmin.h"
-#include "ScintillaEditView.h"
-#include "localization.h"
-#include "Processus.h"
+
+#include <algorithm>
+#include <cctype>
+#include <cwchar>
+#include <string>
+#include <utility>
+#include <vector>
+
+#ifdef NDEBUG
+#include <cstring>
+#else
+#include <exception>
+#include <fstream>
+#endif
+
+#include <json.hpp>
+
+#include "Common.h"
+#include "ListView.h"
+#include "Notepad_plus_msgs.h"
+#include "NppDarkMode.h"
+#include "Parameters.h"
 #include "PluginsManager.h"
+#include "StaticDialog.h"
+#include "localization.h"
+#include "menuCmdID.h"
+#include "pluginsAdminRes.h"
+#include "resource.h"
+
+#ifdef NDEBUG
 #include "verifySignedfile.h"
+#endif
 
 #define TEXTFILE        256
 #define IDR_PLUGINLISTJSONFILE  101
@@ -36,8 +61,7 @@ using namespace std;
 using nlohmann::json;
 
 
-
-wstring PluginUpdateInfo::describe()
+std::wstring PluginUpdateInfo::describe() const
 {
 	wstring desc;
 	const wchar_t *EOL = L"\r\n";
@@ -65,7 +89,7 @@ wstring PluginUpdateInfo::describe()
 }
 
 /// Try to find in the Haystack the Needle - ignore case
-bool findStrNoCase(const wstring & strHaystack, const wstring & strNeedle)
+static bool findStrNoCase(const std::wstring& strHaystack, const std::wstring& strNeedle)
 {
 	auto it = std::search(
 		strHaystack.begin(), strHaystack.end(),
@@ -383,11 +407,11 @@ bool PluginsAdminDlg::removePlugins()
 	return exitToInstallRemovePlugins(pa_remove, puis);
 }
 
-void PluginsAdminDlg::changeTabName(LIST_TYPE index, const wchar_t *name2change)
+void PluginsAdminDlg::changeTabName(LIST_TYPE index, wchar_t* name2change)
 {
 	TCITEM tie{};
 	tie.mask = TCIF_TEXT;
-	tie.pszText = (wchar_t *)name2change;
+	tie.pszText = name2change;
 	TabCtrl_SetItem(_tab.getHSelf(), index, &tie);
 
 	wchar_t label[MAX_PATH]{};
@@ -453,7 +477,7 @@ void PluginViewList::pushBack(PluginUpdateInfo* pi)
 // "[8.3,]"       : any version from 8.3 to the latest one
 // "[,8.2.1]"     : 8.2.1 and any previous version
 //
-std::pair<Version, Version> getIntervalVersions(wstring intervalVerStr)
+static std::pair<Version, Version> getIntervalVersions(std::wstring intervalVerStr)
 {
 	std::pair<Version, Version> result;
 
@@ -461,11 +485,11 @@ std::pair<Version, Version> getIntervalVersions(wstring intervalVerStr)
 		return result;
 
 	const size_t indexEnd = intervalVerStr.length() - 1;
-	if (intervalVerStr[0] == '[' && intervalVerStr[indexEnd] == ']') // interval versions format
+	if (intervalVerStr[0] == L'[' && intervalVerStr[indexEnd] == L']') // interval versions format
 	{
 		wstring cleanIntervalVerStr = intervalVerStr.substr(1, indexEnd - 1);
 		vector<wstring> versionVect;
-		cutStringBy(cleanIntervalVerStr.c_str(), versionVect, ',', true);
+		cutStringBy(cleanIntervalVerStr.c_str(), versionVect, L',', true);
 		if (versionVect.size() == 2)
 		{
 			if (!versionVect[0].empty() && !versionVect[1].empty()) // "[4.2,6.6.6]" : from version 4.2 to 6.6.6 inclusive
@@ -483,7 +507,7 @@ std::pair<Version, Version> getIntervalVersions(wstring intervalVerStr)
 			}
 		}
 	}
-	else if (intervalVerStr[0] != '[' && intervalVerStr[indexEnd] != ']') // one version format -> "6.9" : exact version 6.9
+	else if (intervalVerStr[0] != L'[' && intervalVerStr[indexEnd] != L']') // one version format -> "6.9" : exact version 6.9
 	{
 		result.first = Version(intervalVerStr);
 		result.second = Version(intervalVerStr);
@@ -500,7 +524,7 @@ std::pair<Version, Version> getIntervalVersions(wstring intervalVerStr)
 // "[4.2,6.6.6][6.4,8.9]"  : The 1st interval from version 4.2 to 6.6.6 inclusive, the 2nd interval from version 6.4 to 8.9
 // "[8.3,][6.9,6.9]"       : The 1st interval any version from 8.3 to the latest version, the 2nd interval present only version 6.9
 // "[,8.2.1][4.4,]"        : The 1st interval 8.2.1 and any previous version, , the 2nd interval any version from 4.4 to the latest version
-std::pair<std::pair<Version, Version>, std::pair<Version, Version>> getTwoIntervalVersions(const wstring& twoIntervalVerStr)
+static std::pair<std::pair<Version, Version>, std::pair<Version, Version>> getTwoIntervalVersions(const std::wstring& twoIntervalVerStr)
 {
 	std::pair<std::pair<Version, Version>, std::pair<Version, Version>> r;
 	wstring sep = L"][";
@@ -517,7 +541,7 @@ std::pair<std::pair<Version, Version>, std::pair<Version, Version>> getTwoInterv
 	return r;
 }
 
-bool loadFromJson(std::vector<PluginUpdateInfo*>& pl, wstring& verStr, const json& j)
+static bool loadFromJson(std::vector<PluginUpdateInfo*>& pl, std::wstring& verStr, const json& j)
 {
 	if (j.empty())
 		return false;
@@ -616,13 +640,13 @@ bool loadFromJson(std::vector<PluginUpdateInfo*>& pl, wstring& verStr, const jso
 	return true;
 }
 
-PluginUpdateInfo::PluginUpdateInfo(const wstring& fullFilePath, const wstring& filename)
+PluginUpdateInfo::PluginUpdateInfo(const std::wstring& fullFilePath, const std::wstring& fileName)
 {
 	if (!doesFileExist(fullFilePath.c_str()))
 		return;
 
 	_fullFilePath = fullFilePath;
-	_displayName = filename;
+	_displayName = fileName;
 
 	std::string content = getFileContent(fullFilePath.c_str());
 	if (content.empty())
@@ -631,9 +655,6 @@ PluginUpdateInfo::PluginUpdateInfo(const wstring& fullFilePath, const wstring& f
 	_version.setVersionFrom(fullFilePath);
 }
 
-typedef const char * (__cdecl * PFUNCGETPLUGINLIST)();
-
-
 bool PluginsAdminDlg::initFromJson()
 {
 	// GUP.exe doesn't work under XP
@@ -727,9 +748,6 @@ bool PluginsAdminDlg::updateList()
 	// initialize the primary view with the plugin list loaded from json 
 	initAvailablePluginsViewFromList();
 
-	// initialize update list view
-	checkUpdates();
-
 	// initialize incompatible list view
 	initIncompatiblePluginList();
 
@@ -985,18 +1003,13 @@ bool PluginViewList::hideFromListIndex(size_t index2hide)
 	return true;
 }
 
-bool PluginsAdminDlg::checkUpdates()
-{
-	return true;
-}
-
 // begin insentive-case search from the second key-in character
 bool PluginsAdminDlg::searchInPlugins(bool isNextMode) const
 {
-	constexpr int maxLen = 256;
+	static constexpr int maxLen = 256;
 	wchar_t txt2search[maxLen]{};
 	::GetDlgItemText(_hSelf, IDC_PLUGINADM_SEARCH_EDIT, txt2search, maxLen);
-	if (lstrlen(txt2search) < 2)
+	if (std::wcslen(txt2search) < 2)
 		return false;
 
 	HWND tabHandle = _tab.getHSelf();
